var geodashboardRoot = require('system').env['PWD'];
var app = require(geodashboardRoot + '/app.json');

casper.test.begin('Geodashboard Detail View', 1, function suite(test) {
    var url, screenshotRoot, modules, phantomCSS, page;

    url             = "http://localhost:9000/#detail/location/GREON-01/";
    screenshotRoot  = 'results/screenshots';
    modules         = geodashboardRoot + '/node_modules';
    phantomCSS      = require(modules + '/phantomcss/phantomcss.js');
    page            = { width: 1024, height: 768 };

    phantomCSS.init({
      screenshotRoot: screenshotRoot,
      failedComparisonsRoot: screenshotRoot + '/failures',
      libraryRoot: modules + '/phantomcss',
      cleanupComparisonImages: true,
      comparisonResultRoot: screenshotRoot + '/results'
    });

    casper.start(url);
    casper.viewport(page.width, page.height);

    casper.options.waitTimeout = 60000; // set a 60 second timeout

    casper.waitFor(function inspectDetailView() {
        return this.evaluate(function() {
            return document.querySelector('#detail-view-header');
        });
    }, function then() {


        test.assertTitle(app.title + " - Details", "the title shows " + app.title + " - Details");

        // for time series tab, ensure number of parameter checkboxes equals the number parameter graphs
        var parameters = this.evaluate(function() {return document.querySelector('#parameters-time')});
        var graphs = this.evaluate(function() { return document.querySelectorAll('.time-series-distribution-charts')});
        test.assertEquals(parameters.length, graphs.length, "Number of parameter checkboxes and parameter graphs is the same.");
        phantomCSS.screenshot('#detail-panel', 'detail-GREON-01');
    });


//    bamboo won't compare screenshots since the screenshots folder is empty on each new build
//    uncomment this if you want to compare screenshots
//    casper.then( function now_check_the_screenshots(){
//      // compare screenshots
//      phantomCSS.compareAll();
//    });

    /*
     Casper runs tests
     */
    casper.run(function(){
      test.done();
      console.log('\nTHE END.');
      phantom.exit(phantomCSS.getExitStatus());
    });
});
